@@ -9,6 +9,11 @@ final class KeyStream implements Comparable<KeyStream> {
 	cur = 0;
     }
 
+    public KeyStream(String key, int start) {
+	s   = key;
+	cur = start;
+    }
+
     public int compareTo(KeyStream ks) {
 	return s.substring(cur).compareTo(ks.s.substring(ks.cur));
     }
